%define ALD_Ver		2.0
%define USE_TOPOLOGY	0

Name:         alsa-lib

License:      LGPLv2+
Summary:      The Advanced Linux Sound Architecture (ALSA) library
Version:      1.2.11
Release:      0

URL:          http://www.alsa-project.org/
#https://www.alsa-project.org/files/pub/lib/

Source: %{name}-%{version}.tar.xz

#https://github.com/alsa-project/alsa-ucm-conf
Source1:  alsa-ucm-conf-%{version}.tar.xz
%if %{USE_TOPOLOGY}
Source2:  alsa-topology-conf-%{version}.tar.bz2
%endif

Source3: %{name}-%{version}-patches.tgz

%define DestDir		/Multimedia
# -----------------------------------------------------

%if %{_target_cpu} == %{_build_cpu}
%define _srcrpmdir	%{_topdir}/SRPMS/%{ALD_Ver}
%define _CROSS 0
%define MakeLocCross 0
%else
# rpm --target=armv7hl -ba xxxxx.spec
%define _srcrpmdir	%{_topdir}/SRPMS/tmp
%define _CROSS 1
%define MakeLocCross 1
%define _host %{_arch}-%{_os}%{_gnu}
%endif

#------------------ CROSS DIR --------------------

%define docdir		%{_defaultdocdir}/%{name}

%define auto_local %{_sourcedir}/AUTO_LOCAL-1.sh
%define have_auto_local %(if test -x %{auto_local} ; then echo 1 ; else echo 0 ; fi)

%if %{have_auto_local}
%define __os_install_post %{nil}
%define CrossPath	%(%{auto_local} -GetCrossPath -build_cpu=%{_build_cpu} -target_cpu=%{_target_cpu})
%endif

# ------------------- description ------------------------------------
%description
The Advanced Linux Sound Architecture (ALSA) provides audio and MIDI
functionality to the Linux operating system.
#-------------------------------
%package devel
Summary:      Libraries for the C compiler
%description devel
These libraries are needed to compile C code.
#-------------------------------
%package %{_target_cpu}
Summary:      %{name} Cross-%{_target_cpu}
Buildarch:    noarch
autoreqprov:  0
%description %{_target_cpu}
%{name} Cross-%{_target_cpu}

# ------------------- setup ------------------------------------------
%Prep
%setup -q -n %{name}-%{version}
tar -xaf %{SOURCE1}
%if %{USE_TOPOLOGY}
tar -xaf %{SOURCE2}
%endif

tar -xaf %SOURCE3
patch -b -z .orig -p0<patches/config.patch

# ------------------- Build ------------------------------------------
%Build
%if %{_CROSS}
export  PATH="%{CrossPath}/bin:$PATH"
export GCC_NoHostPath=d
%endif

%if %{_arch} == "i386"
OPTFLAGS="-O2 -march=i586 -mpreferred-stack-boundary=2 -falign-functions=1 -falign-jumps=1 -falign-loops=1 -fomit-frame-pointer"
%endif
%if %{_arch} == "x86_64"
OPTFLAGS="-O2"
%endif
%if %{_arch} == "arm"
OPTFLAGS="%{optflags} -O2 -munaligned-access"
%endif

OPTFLAGS="$OPTFLAGS -fno-asynchronous-unwind-tables"

CFLAGS="$OPTFLAGS -std=gnu99"
LDFLAGS="-Wl,--gc-sections"
CXXFLAGS="$OPTFLAGS"
export INSTALL="/usr/bin/install -p -c"

%configure \
	--disable-libtool-lock \
	--disable-aload \
%if %{USE_TOPOLOGY}
	--enable-topology \
%else
	--disable-topology \
%endif
	--disable-alisp \
	&>FConfigure_log.txt

# Remove useless /usr/lib64 rpath on 64bit archs
#sed -i 's|^hardcode_libdir_flag_spec=.*|hardcode_libdir_flag_spec=""|g' libtool
#sed -i 's|^runpath_var=LD_RUN_PATH|runpath_var=DIE_RPATH_DIE|g' libtool

make V=1 &>FMake_log.txt

# ------------------- Install ----------------------------------------
%Install
%if %{_CROSS}
export  PATH="%{CrossPath}/bin:$PATH"
export GCC_NoHostPath=d
%endif

rm -rf $RPM_BUILD_ROOT
mkdir -p %{_srcrpmdir}
mkdir -p $RPM_BUILD_ROOT%{docdir}

make DESTDIR=$RPM_BUILD_ROOT install &>Finstall_log.txt

rm $RPM_BUILD_ROOT%{_libdir}/*.la

%if %{USE_TOPOLOGY}
cp -a alsa-topology-conf-%{version}/topology $RPM_BUILD_ROOT%{_datadir}/alsa/
%else
rm $RPM_BUILD_ROOT%{_libdir}/pkgconfig/alsa-topology.pc
%endif
#cp -a alsa-ucm-conf-%{version}/ucm $RPM_BUILD_ROOT%{_datadir}/alsa/
cp -a alsa-ucm-conf-%{version}/ucm2 $RPM_BUILD_ROOT%{_datadir}/alsa/

ln -s /usr/share/doc/lgpl-2.1.txt $RPM_BUILD_ROOT%{docdir}/COPYING
cp -a doc/asoundrc.txt $RPM_BUILD_ROOT%{docdir}/

%if %{have_auto_local}
  %{auto_local} -build_cpu=%{_build_cpu} -target_cpu=%{_target_cpu} \
	-MakeLocCross=%{MakeLocCross} -DelLocCrossDir=%{_bindir}
%endif  # have_auto_local

%{_rpmconfigdir}/check-rpaths

# ------------------- Clean ------------------------------------------
%Clean

%if %{have_auto_local}
  %{auto_local} -build_cpu=%{_build_cpu} -target_cpu=%{_target_cpu} \
	-MakeLocCross=%{MakeLocCross} \
	-ALD_Ver=%{ALD_Ver} -RpmMovePath=%{DestDir} -tar_arg=bzip2
%endif  # have_auto_local

# ------------------- Files ------------------------------------------
%files
%{_bindir}/aserver
%{_libdir}/libasound.so.*
%dir %{_datadir}/alsa
%{_datadir}/alsa/cards
%{_datadir}/alsa/ctl
%{_datadir}/alsa/pcm
%{_datadir}/alsa/ucm2
%{_datadir}/alsa/alsa.conf
%{docdir}

%files devel
%{_includedir}
%{_libdir}/libasound.so
%{_libdir}/pkgconfig/alsa.pc
%{_datadir}/aclocal/alsa.m4

# ------------------- Cross Files ------------------------------------
%if %{MakeLocCross} && %{have_auto_local}

%files %{_target_cpu}
%{CrossPath}%{_libdir}
%{CrossPath}%{_includedir}
%{CrossPath}%{docdir}

%endif # MakeLocCross
